Struct predicates::iter::HashableInPredicate [−][src]
Predicate that returns true if variable is a member of the pre-defined
HashSet, otherwise returns false.
Note that this implementation requires Item to be Hash + Eq. The
InPredicate uses a less efficient search algorithm but only
requires Item implement PartialEq. The implementation-specific
predicates will be deprecated when Rust supports trait specialization.
This is created by the predicate::in_hash function.