[−][src]Module predicates::str
String Predicates
This module contains predicates specific to string handling.
Structs
| ContainsPredicate | Predicate that checks for patterns. |
| DifferencePredicate | Predicate that diffs two strings. |
| EndsWithPredicate | Predicate checks end of str |
| IsEmptyPredicate | Predicate that checks for empty strings. |
| MatchesPredicate | Predicate that checks for repeated patterns. |
| NormalizedPredicate | Predicate adapter that normalizes the newlines contained in the variable being tested. |
| RegexPredicate | Predicate that uses regex matching |
| StartsWithPredicate | Predicate checks start of str |
| TrimPredicate | Predicate adaper that trims the variable being tested. |
| Utf8Predicate | Predicate adaper that converts a |
Traits
| PredicateStrExt |
|
Functions
| contains | Creates a new |
| diff | Creates a new |
| ends_with | Creates a new |
| is_empty | Creates a new |
| is_match | Creates a new |
| similar | Creates a new |
| starts_with | Creates a new |
Type Definitions
| RegexError | An error that occurred during parsing or compiling a regular expression. |